import { Box, HStack, Stack } from "@styled-system/jsx";
import { getAbout, getContact } from "@/api";

import { Heading } from "@/components/ui/heading";
import { Text } from "@/components/ui/text";
import { getI18n } from "@/i18n/server";
import { getOpeningTimes } from "@/api/openingTimes";
import { styled } from "@styled-system/jsx";

export default async function Contact() {
  const t = await getI18n();
  const about = await getAbout();
  const contact = await getContact();
  const openingTimes = await getOpeningTimes();

  return (
    <Stack p={6} gap={10}>
      <Heading as="h1" size="3xl">
        {t("general.contact")}
      </Heading>

      <Stack>
        <Heading as="h3" size="xl">
          {t("general.openingTimes")}
        </Heading>
        {openingTimes.docs.map((ot) => (
          <HStack key={ot.id}>
            <Text w={250}>
              {t(`days.${ot.from}`)}
              {ot.to ? `- ${t(`days.${ot.to}`)}` : ""}
            </Text>
            <Text>
              {new Date(ot.timeOpen).toLocaleTimeString("de-CH", { timeStyle: "short" })} -{" "}
              {new Date(ot.timeClose).toLocaleTimeString("de-CH", { timeStyle: "short" })}
            </Text>
          </HStack>
        ))}
      </Stack>

      <Stack>
        <Heading as="h3" size="xl">
          {t("general.address")}
        </Heading>
        <HStack gap={20}>
          {contact.address.embeddedMaps && (
            <styled.div
              dangerouslySetInnerHTML={{ __html: contact.address.embeddedMaps }}
              width={600}
            />
          )}
          <Stack>
            <Box>
              <Text fontWeight="bold">{about.name}</Text>
              <Text>
                {contact.address.street} {contact.address.number}
              </Text>
              <Text>
                {contact.address.zip} {contact.address.area}
              </Text>
            </Box>
            {contact.phone && (
              <HStack>
                <Text fontWeight="bold">{t("general.phoneNumber")}</Text>
                <Text>{contact.phone}</Text>
              </HStack>
            )}
            {contact.email && (
              <HStack>
                <Text fontWeight="bold">{t("general.email")}</Text>
                <Text>{contact.email}</Text>
              </HStack>
            )}
          </Stack>
        </HStack>
      </Stack>
    </Stack>
  );
}
