import "../../globals.css";

import Footer from "@/components/layout/footer";
import { I18nProviderClient } from "@/i18n/client";
import { Metadata } from "next";
import Navbar from "@/components/layout/navbar";
import { getAbout } from "@/api";
import localFont from "next/font/local";
import { locales } from "@/i18n/settings";
import { styled } from "@styled-system/jsx";

const moderustic = localFont({
  src: "./Moderustic-VariableFont_wght.ttf",
  display: "swap",
});

export default async function RootLayout({
  params: { locale },
  children,
}: {
  params: { locale: string };
  children: React.ReactNode;
}) {
  return (
    <html lang={locale}>
      <I18nProviderClient locale={locale}>
        <styled.body className={moderustic.className}>
          <Navbar />
          <styled.main mt={20} pb={20}>
            {children}
          </styled.main>
          <Footer />
        </styled.body>
      </I18nProviderClient>
    </html>
  );
}

export async function generateStaticParams() {
  return locales.map((locale) => ({ locale }));
}

export async function generateMetadata(): Promise<Metadata> {
  const about = await getAbout();

  return {
    title: about.name,
  };
}
