import { Box, HStack, Stack } from "@styled-system/jsx";

import { HoverCard } from "@/components/ui/hover-card";
import { IconButton } from "@/components/ui/icon-button";
import Image from "next/image";
import { Image as ImageIcon } from "lucide-react";
import { Media } from "@/payload-types";
import RichText from "@/components/rich-text";
import { TabContentBaseProps } from "@ark-ui/react";
import { Tabs } from "@/components/ui/tabs";
import { Text } from "@/components/ui/text";
import { css } from "@styled-system/css";
import { formatToCHF } from "@/utils/formatters";
import { getMenuItems } from "@/api";
import { locales } from "@/i18n/settings";

export default async function CategoryTabContent({
  locale,
  ...props
}: { locale: (typeof locales)[number] } & TabContentBaseProps) {
  const menuItems = await getMenuItems({
    locale,
    where: { category: { equals: props.value } },
    pagination: false,
  });

  return (
    <Tabs.Content {...props}>
      <Stack>
        {menuItems.docs.map((mi) => (
          <HStack key={mi.id} alignItems="start">
            <Stack marginRight="auto">
              <HStack>
                <Text>{mi.name}</Text>
                {mi.image && (
                  <HoverCard.Root>
                    <HoverCard.Trigger asChild>
                      <IconButton variant="ghost">
                        <ImageIcon />
                      </IconButton>
                    </HoverCard.Trigger>
                    <HoverCard.Positioner>
                      <HoverCard.Content>
                        <HoverCard.Arrow>
                          <HoverCard.ArrowTip />
                        </HoverCard.Arrow>
                        <Box w={250} h={150} position="relative">
                          <Image
                            src={(mi.image as Media).url!}
                            alt={(mi.image as Media).alt ?? ""}
                            className={css({ objectFit: "cover" })}
                            fill
                          />
                        </Box>
                      </HoverCard.Content>
                    </HoverCard.Positioner>
                  </HoverCard.Root>
                )}
              </HStack>
              {mi.description && (
                <RichText content={mi.description} className={css({ color: "fg.muted" })} />
              )}
            </Stack>
            <HStack justify="end">
              {mi.variants.map((v) => (
                <Stack key={v.id} align="end">
                  <Text>{formatToCHF(v.price!)}</Text>
                  <Text color="fg.muted">{v.title}</Text>
                </Stack>
              ))}
            </HStack>
          </HStack>
        ))}
      </Stack>
    </Tabs.Content>
  );
}
