import { Box, Stack } from "@styled-system/jsx";

import CategoryTabContent from "./category-tab-content";
import { Heading } from "@/components/ui/heading";
import { Params } from "../shared";
import { Tabs } from "@/components/ui/tabs";
import { getI18n } from "@/i18n/server";
import { getMenuCategories } from "@/api";

export default async function Menu({ params: { locale } }: { params: Params }) {
  const t = await getI18n();
  const menuCategories = await getMenuCategories();

  return (
    <Stack p={6} align="center">
      <Heading as="h1" size="3xl">
        {t("general.menu")}
      </Heading>
      <Box maxW="3xl" w="100%">
        <Tabs.Root defaultValue={menuCategories.docs[0].id} orientation="horizontal" w="100%">
          <Tabs.List>
            {menuCategories.docs.map((mc) => (
              <Tabs.Trigger key={mc.id} value={mc.id}>
                {mc.name}
              </Tabs.Trigger>
            ))}
            <Tabs.Indicator />
          </Tabs.List>
          {menuCategories.docs.map((mc) => (
            <CategoryTabContent key={mc.id} value={mc.id} locale={locale}></CategoryTabContent>
          ))}
        </Tabs.Root>
      </Box>
    </Stack>
  );
}
