import { Box, HStack, Stack, styled } from "@styled-system/jsx";
import { getAbout, getContact } from "@/api";

import { IconButton } from "@/components/ui/icon-button";
import { SiFacebook } from "@icons-pack/react-simple-icons";
import { Text } from "@/components/ui/text";
import { stack } from "@styled-system/patterns";

export default async function Footer() {
  const about = await getAbout();
  const contact = await getContact();

  return (
    <styled.footer h={60} p={8} className={stack({ gap: 4, justify: "end" })}>
      <HStack justify="space-between" alignItems="start">
        <Box>
          <Text fontWeight="bold">{about.name}</Text>
          <Text>
            {contact.address.street} {contact.address.number}
          </Text>
          <Text>
            {contact.address.zip} {contact.address.area}
          </Text>
        </Box>
        <HStack>
          {(contact.socialLinks ?? []).map((sl) => (
            <IconButton key={sl.id} asChild variant="link">
              <a href={sl.link}>
                <SiFacebook />
              </a>
            </IconButton>
          ))}
        </HStack>
        <Stack gap={2}>
          {contact.phone && <styled.a href={`tel:${contact.phone}`}>{contact.phone}</styled.a>}
          {contact.email && <styled.a href={`mailto:${contact.email}`}>{contact.email}</styled.a>}
        </Stack>
      </HStack>
      <Text textAlign="center">Powered by Jenyus</Text>
    </styled.footer>
  );
}
