"use client";

import { About, Media } from "@/payload-types";
import { Menu, X } from "lucide-react";

import { IconButton } from "@/components/ui/icon-button";
import Image from "next/image";
import Link from "next/link";
import NavLink from "@/components/layout/nav-link";
import { css } from "@styled-system/css";
import { styled } from "@styled-system/jsx";
import { useI18n } from "@/i18n/client";
import { useState } from "react";

export default function MobileNav({ about }: { about: About }) {
  const [show, setShow] = useState(false);
  const t = useI18n();

  return (
    <styled.div className={css({ display: "block", sm: { display: "none" } })}>
      <IconButton onClick={() => setShow((show) => !show)}>
        <Menu />
      </IconButton>
      <styled.div
        display={show ? "flex" : "none"}
        zIndex={600}
        position="fixed"
        top={0}
        left={0}
        right={0}
        bottom={0}
        height="100%"
        width="100%"
        flexDir="column"
        gap={4}
        p={12}
        bg="white"
        alignItems="center"
        onClick={() => setShow(false)}
      >
        <styled.div alignSelf="stretch" display="flex" justifyContent="end">
          <IconButton variant="ghost" onClick={() => setShow(false)}>
            <X />
          </IconButton>
        </styled.div>

        {about.logo ? (
          <Link href="/" className={css({ h: 16, w: 200, position: "relative" })}>
            <Image
              src={(about.logo as Media).url!}
              alt={(about.logo as Media).alt ?? about.name}
              className={css({ objectFit: "contain" })}
              fill
            />
          </Link>
        ) : (
          <Link href="/" className={css({ fontSize: 24 })}>
            {about.name}
          </Link>
        )}

        <NavLink href="/">{t("general.home")}</NavLink>
        <NavLink href="/about">{t("general.about")}</NavLink>
        <NavLink href="/menu">{t("general.menu")}</NavLink>

        <NavLink
          href="/contact"
          type="button"
          className={css({ alignSelf: "stretch", textAlign: "center", marginTop: "auto" })}
        >
          {t("general.contact")}
        </NavLink>
      </styled.div>
    </styled.div>
  );
}
