import Image from "next/image";
import LanguagePicker from "./language-picker";
import Link from "next/link";
import { Media } from "@/payload-types";
import MobileNav from "./mobile-nav";
import NavLink from "./nav-link";
import { css } from "@styled-system/css";
import { flex } from "@styled-system/patterns";
import { getAbout } from "@/api";
import { getI18n } from "@/i18n/server";
import { styled } from "@styled-system/jsx";

export default async function Navbar() {
  const t = await getI18n();
  const about = await getAbout();

  return (
    <styled.nav
      className={flex({ gap: 4 })}
      bg="white"
      h={20}
      px={4}
      boxShadow="lg"
      alignItems="center"
      position="fixed"
      zIndex={500}
      top={0}
      left={0}
      right={0}
      width="100%"
    >
      {about.logo ? (
        <Link href="/" className={css({ h: 16, w: 200, position: "relative" })}>
          <Image
            src={(about.logo as Media).url!}
            alt={(about.logo as Media).alt ?? about.name}
            className={css({ objectFit: "contain", objectPosition: "left" })}
            fill
          />
        </Link>
      ) : (
        <Link href="/" className={css({ fontSize: 24 })}>
          {about.name}
        </Link>
      )}
      <styled.div flexGrow={1} />

      <NavLink href="/about" className={css({ display: "none", sm: { display: "block" } })}>
        {t("general.about")}
      </NavLink>
      <NavLink href="/menu" className={css({ display: "none", sm: { display: "block" } })}>
        {t("general.menu")}
      </NavLink>

      <NavLink
        href="/contact"
        type="button"
        className={css({ display: "none", sm: { display: "block" } })}
      >
        {t("general.contact")}
      </NavLink>

      <LanguagePicker />

      <MobileNav about={about} />
    </styled.nav>
  );
}
