import { css, cx } from "@styled-system/css";

import React from "react";
import { container } from "@styled-system/patterns";
import { serializeLexical } from "./serialize";

type Props = {
  className?: string;
  content: Record<string, any>;
  enableGutter?: boolean;
  enableProse?: boolean;
};

const RichText: React.FC<Props> = ({ className, content, enableGutter = false }) => {
  if (!content) {
    return null;
  }

  return (
    <div className={cx(enableGutter ? container() : css({ maxW: "none" }), className)}>
      {content &&
        !Array.isArray(content) &&
        typeof content === "object" &&
        "root" in content &&
        serializeLexical({ nodes: content?.root?.children })}
    </div>
  );
};

export default RichText;
