import { DefaultTranslationsObject, Language } from "@payloadcms/translations";

import { About } from "./globals/About";
import { Contact } from "./globals/Contact";
import { FoodDeclaration } from "./collections/FoodDeclaration";
import { Gallery } from "@/globals/Gallery";
import { Holiday } from "./collections/Holiday";
import { Home } from "./globals/Home";
import { Media } from "./collections/Media";
import { Menu } from "./globals/Menu";
import { MenuCategory } from "./collections/MenuCategory";
import { MenuItem } from "./collections/MenuItem";
import { MenuItemTag } from "./collections/MenuItemTag";
import { OpeningTime } from "./collections/OpeningTime";
import { Users } from "./collections/Users";
import { Vacation } from "./collections/Vacation";
import { buildConfig } from "payload";
import { de } from "@payloadcms/translations/languages/de";
import { en } from "@payloadcms/translations/languages/en";
import { fileURLToPath } from "url";
import { fr } from "@payloadcms/translations/languages/fr";
import { it } from "@payloadcms/translations/languages/it";
import { lexicalEditor } from "@payloadcms/richtext-lexical";
// storage-adapter-import-placeholder
import { mongooseAdapter } from "@payloadcms/db-mongodb";
import path from "path";
import sharp from "sharp";

const filename = fileURLToPath(import.meta.url);
const dirname = path.dirname(filename);

export default buildConfig({
  admin: {
    user: Users.slug,
    importMap: {
      baseDir: path.resolve(dirname),
    },
  },
  collections: [
    Users,
    Media,
    OpeningTime,
    MenuItem,
    MenuCategory,
    MenuItemTag,
    FoodDeclaration,
    Vacation,
    Holiday,
  ],
  globals: [Home, Gallery, About, Contact, Menu],
  editor: lexicalEditor(),
  secret: process.env.PAYLOAD_SECRET || "",
  typescript: {
    outputFile: path.resolve(dirname, "payload-types.ts"),
  },
  db: mongooseAdapter({
    url: process.env.DATABASE_URI || "",
  }),
  sharp,
  plugins: [
    // storage-adapter-placeholder
  ],
  i18n: {
    fallbackLanguage: "de",
    supportedLanguages: {
      en: en as Language<DefaultTranslationsObject>,
      de: de as Language<DefaultTranslationsObject>,
      fr: fr as Language<DefaultTranslationsObject>,
      it: it as Language<DefaultTranslationsObject>,
    },
  },
  localization: {
    locales: [
      {
        label: {
          de: "Deutsch",
          en: "German",
        },
        code: "de",
      },
      {
        label: {
          fr: "Français",
          en: "French",
          de: "Französisch",
        },
        code: "fr",
      },
      {
        label: {
          it: "Italiano",
          de: "Italienisch",
          en: "Italian",
        },
        code: "it",
      },
      {
        label: {
          de: "Englisch",
          en: "English",
        },
        code: "en",
      },
    ],
    defaultLocale: "de",
    fallback: true,
  },
});
